==> nip2_7.24.1.orig.tar.gz: nip2-7.24.1/src/iregiongroup.h <==
/* base model for a client regions on an imageview
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

 */

#define TYPE_IREGIONGROUP (iregiongroup_get_type())
#define IREGIONGROUP( obj ) \
	(G_TYPE_CHECK_INSTANCE_CAST( (obj), TYPE_IREGIONGROUP, iRegiongroup ))
#define IREGIONGROUP_CLASS( klass ) \
	(G_TYPE_CHECK_CLASS_CAST( (klass), \
		TYPE_IREGIONGROUP, iRegiongroupClass))
#define IS_IREGIONGROUP( obj ) \
	(G_TYPE_CHECK_INSTANCE_TYPE( (obj), TYPE_IREGIONGROUP ))
#define IS_IREGIONGROUP_CLASS( klass ) \
	(G_TYPE_CHECK_CLASS_TYPE( (klass), TYPE_IREGIONGROUP ))
#define IREGIONGROUP_GET_CLASS( obj ) \
	(G_TYPE_INSTANCE_GET_CLASS( (obj), \
		TYPE_IREGIONGROUP, iRegiongroupClass ))

struct _iRegiongroup {
	Classmodel parent_class;

};

typedef struct _iRegiongroupClass {
	ClassmodelClass parent_class;

	/* My methods.
	 */
} iRegiongroupClass;

GType iregiongroup_get_type( void );
iRegiongroup *iregiongroup_new( Classmodel *classmodel );

==> nip-7.8.14.tar.gz: nip-7.8.14/src/iregiongroup.h <==
/* base model for a client regions on an imageview
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

 */

#define TYPE_IREGIONGROUP (iregiongroup_get_type())
#define IREGIONGROUP( obj ) \
	(GTK_CHECK_CAST( (obj), TYPE_IREGIONGROUP, Iregiongroup ))
#define IREGIONGROUP_CLASS( klass ) \
	(GTK_CHECK_CLASS_CAST( (klass), TYPE_IREGIONGROUP, IregiongroupClass ))
#define IS_IREGIONGROUP( obj ) (GTK_CHECK_TYPE( (obj), TYPE_IREGIONGROUP ))
#define IS_IREGIONGROUP_CLASS( klass ) \
	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_IREGIONGROUP ))

struct _Iregiongroup {
	Classmodel parent_class;

};

typedef struct _IregiongroupClass {
	ClassmodelClass parent_class;

	/* My methods.
	 */
} IregiongroupClass;

GtkType iregiongroup_get_type( void );
Iregiongroup *iregiongroup_new( Classmodel *classmodel );
